TcccCallUI class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCallUIDismissed() → void
override
onCallUIRequested(Session call) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isShowing → bool
no setter

Static Methods

dismiss() → Future<void>
install({required GlobalKey<NavigatorState> navigatorKey, TcccCallUIOptions options = const TcccCallUIOptions()}) → void
show() → Future<void>
uninstall() → void
updateOptions(TcccCallUIOptions options) → void