TcccCallUIOptions class

Constructors

TcccCallUIOptions({Widget avatarBuilder(BuildContext, Session)?, bool showDialPad = true, bool showSpeakerToggle = true, bool autoPopOnEnded = true, Duration endedLingerDuration = const Duration(milliseconds: 1500), bool confirmHangupWhenConnected = false, Locale? locale, ThemeMode themeMode = ThemeMode.system, Widget pageBuilder(BuildContext, Session)?})
const

Properties

autoPopOnEnded → bool
final
avatarBuilder → Widget Function(BuildContext, Session)?
final
confirmHangupWhenConnected → bool
final
endedLingerDuration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
locale → Locale?
Call-page language. Wins over TcccConfig.locale and the ambient MaterialApp locale. Same split as L0: only en is English.
final
pageBuilder → Widget Function(BuildContext, Session)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDialPad → bool
final
showSpeakerToggle → bool
final
themeMode → ThemeMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited