FakeTcccCall class
Scriptable Session for widget and golden tests. Not a production handle.
- Implemented types
Constructors
- FakeTcccCall({String callId = 'fake-call', String channelId = '10086', DateTime? startedAt, TcccCallSnapshot? status, TcccCallResult? result, TcccOutcome dtmfResultBuilder(String digit)?})
- FakeTcccCall.state(TcccCallState state, {TcccMediaMode mediaMode = TcccMediaMode.trtc, bool? isInRoom, String callId = 'fake-call', String channelId = '10086', String? peerDisplayName = 'Service', String? peerSubtitle, bool isMuted = false, TcccAudioRoute audioRoute = TcccAudioRoute.earpiece, bool reconnecting = false, TcccCause endedCause = TcccCause.terminated, TcccOriginator endedOriginator = TcccOriginator.local})
-
factory
Properties
- callId → String
-
final
- channelId → String
-
final
- direction → TcccCallDirection
-
no setteroverride
- dtmfResultBuilder ↔ TcccOutcome Function(String digit)?
-
getter/setter pair
-
ended
→ Future<
TcccCallResult> -
no setteroverride
-
events
→ Stream<
TcccEvent> -
This call's events (
callIdmatches). Switch on TcccEvent.type (progress,accepted,confirmed,newDTMF, … / TcccEventType). WSS stays onTcccUserCall.events; TRTC reconnect uses TcccServerType.trtc here.acceptedis SIP 200; talkable is isEstablished.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- isEnded → bool
-
no setteroverride
- isEstablished → bool
-
Talkable:
state == accepted(joined or IVR). Not the SIPacceptedevent. DTMF requires this.no setteroverride - isInProgress → bool
-
Setup in progress:
preparing/calling/earlyMedia.no setteroverride - lastRoute ↔ TcccAudioRoute?
-
getter/setter pair
- milestones → TcccCallMilestones
-
no setteroverride
- muteAudioCount ↔ int
-
getter/setter pair
- result → TcccCallResult?
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sendDtmfHold
↔ Completer<
void> ? -
When set, sendDTMFTone waits here after recording occupancy, so UI tests
can prove echo does not wait on SIP INFO.
getter/setter pair
-
sentDtmf
→ List<
String> -
final
- startedAt → DateTime
-
final
- status → TcccCallSnapshot
-
no setteroverride
-
statusListenable
→ ValueListenable<
TcccCallSnapshot> -
no setteroverride
- terminateCount ↔ int
-
getter/setter pair
Methods
-
completeDone(
TcccCallResult result) → void -
emit(
TcccEvent event) → void -
isMuted(
) → TcccMutedState -
override
-
muteAudio(
bool mute) → Future< TcccOutcome> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendDTMFTone(
String tone, {int? duration, int? interToneGap}) → Future< TcccOutcome> -
override
-
setAudioRoute(
TcccAudioRoute route) → Future< TcccOutcome> -
override
-
setStatus(
TcccCallSnapshot status) → void -
terminate(
) → Future< TcccOutcome> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited