TcccCallUITokens class
Constructors
- TcccCallUITokens({required Color background, required Color surface, required Color hairline, required Color primaryText, required Color secondaryText, required Color controlBackground, required Color controlForeground, required Color controlBackgroundActive, required Color controlForegroundActive, required Color controlDisabled, required Color controlForegroundDisabled, required Color danger, required Color dangerForeground, required Color banner, required Color bannerText, required Color dialPadKey, required Color dialPadKeyPressed, required Color dialPadKeyText, required Color overlayScrim})
-
const
- TcccCallUITokens.dark()
-
factory
- TcccCallUITokens.forBrightness(Brightness brightness)
-
factory
- TcccCallUITokens.light()
-
factory
Properties
- background → Color
-
final
-
final
-
final
- controlBackground → Color
-
final
- controlBackgroundActive → Color
-
final
- controlDisabled → Color
-
final
- controlForeground → Color
-
final
- controlForegroundActive → Color
-
final
- controlForegroundDisabled → Color
-
final
- danger → Color
-
final
- dangerForeground → Color
-
final
- dialPadKey → Color
-
final
- dialPadKeyPressed → Color
-
final
- dialPadKeyText → Color
-
final
- hairline → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayScrim → Color
-
final
- primaryText → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryText → Color
-
final
- surface → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited