TcccLocalizations class
Properties
- backgroundKeepAliveLimited → String
-
no setter
- callEnded → String
-
no setter
- calling → String
-
no setter
- confirmHangupCancel → String
-
no setter
- confirmHangupConfirm → String
-
no setter
- confirmHangupTitle → String
-
no setter
- connected → String
-
no setter
- connectingIvr → String
-
no setter
- dialPad → String
-
no setter
- earpiece → String
-
no setter
- hangUp → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hide → String
-
no setter
- locale → Locale
-
final
- micNotAuthorized → String
-
no setter
- mute → String
-
no setter
- notificationDisabled → String
-
no setter
- phoneAvatar → String
-
no setter
- pound → String
-
no setter
- reconnecting → String
-
no setter
- ringing → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speaker → String
-
no setter
- star → String
-
no setter
- unmute → String
-
no setter
Methods
-
dtmfSemantics(
String digit) → String -
endedReason(
TcccCause cause, {TcccOriginator? originator}) → String -
formatDuration(
Duration d) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
statusText(
TcccCallSnapshot status) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → TcccLocalizations -
resolve(
Locale? locale) → TcccLocalizations -
resolveLocale(
Locale? preferred, Locale? ambient) → Locale
Constants
-
delegate
→ const LocalizationsDelegate<
TcccLocalizations> - en → const TcccLocalizations
- zh → const TcccLocalizations